@@ -21,12 +21,12 @@ test_that("Multiple y's and NA's", {
 
 test_that("The argument date is Date class", {
   expect_error(
-    frame_calendar(pedestrian, x = Time, y = Hourly_Counts, date = Date_Time)
+    frame_calendar(hourly_peds, x = Time, y = Hourly_Counts, date = Date_Time)
   )
 })
 
 test_that("Variable scoping", {
-  ped <- rename(pedestrian, n = Hourly_Counts)
+  ped <- rename(hourly_peds, n = Hourly_Counts)
   expect_named(
     frame_calendar(ped, x = Time, y = n, date = Date),
     c(names(ped), ".Time", ".n")
@@ -34,31 +34,31 @@ test_that("Variable scoping", {
 })
 
 test_that("Some column names of data are used in the function", {
-  ped <- rename(pedestrian, .gx = Date_Time)
+  ped <- rename(hourly_peds, .gx = Date_Time)
   expect_error(
     frame_calendar(ped, x = Time, y = Hourly_Counts, date = Date),
     "must be renamed"
   )
-  ped <- rename(pedestrian, .cx = Date_Time)
+  ped <- rename(hourly_peds, .cx = Date_Time)
   expect_error(
     frame_calendar(ped, x = Time, y = Hourly_Counts, date = Date),
     "must be renamed"
   )
-  ped <- rename(pedestrian, .ymax = Date_Time)
+  ped <- rename(hourly_peds, .ymax = Date_Time)
   expect_error(
     frame_calendar(ped, x = Time, y = Hourly_Counts, date = Date),
     "must be renamed"
   )
-  ped <- rename(pedestrian, theta = Date_Time)
+  ped <- rename(hourly_peds, theta = Date_Time)
   expect_error(
     frame_calendar(ped, x = Time, y = Hourly_Counts, date = Date, polar = TRUE),
     "must be renamed"
   )
-  ped <- rename(pedestrian, theta = Date_Time)
+  ped <- rename(hourly_peds, theta = Date_Time)
   expect_is(
     frame_calendar(ped, x = Time, y = Hourly_Counts, date = Date), "tbl_cal"
   )
-  ped <- rename(pedestrian, .day = Date_Time)
+  ped <- rename(hourly_peds, .day = Date_Time)
   expect_error(
     frame_calendar(
       ped, x = Time, y = Hourly_Counts, date = Date, scale = "free_wday"
@@ -81,15 +81,15 @@ test_that("Some column names of data are used in the function", {
 
 test_that("The argument calendar", {
   mcal <- frame_calendar(
-    pedestrian, x = Time, y = Hourly_Counts, date = Date, calendar = "monthly"
+    hourly_peds, x = Time, y = Hourly_Counts, date = Date, calendar = "monthly"
   )
   expect_match(get_calendar(mcal), "monthly")
   wcal <- frame_calendar(
-    pedestrian, x = Time, y = Hourly_Counts, date = Date, calendar = "weekly"
+    hourly_peds, x = Time, y = Hourly_Counts, date = Date, calendar = "weekly"
   )
   expect_match(get_calendar(wcal), "weekly")
   dcal <- frame_calendar(
-    pedestrian, x = Time, y = Hourly_Counts, date = Date, calendar = "daily"
+    hourly_peds, x = Time, y = Hourly_Counts, date = Date, calendar = "daily"
   )
   expect_match(get_calendar(dcal), "daily")
 })
@@ -97,23 +97,23 @@ test_that("The argument calendar", {
 test_that("The arguments x, y, date are unquoted variables", {
   expect_error(
     frame_calendar(
-      pedestrian, x = "Time", y = Hourly_Counts, date = Date
+      hourly_peds, x = "Time", y = Hourly_Counts, date = Date
     )
   )
   expect_error(
     frame_calendar(
-      pedestrian, x = Time, y = "Hourly_Counts", date = Date
+      hourly_peds, x = Time, y = "Hourly_Counts", date = Date
     )
   )
   expect_error(
     frame_calendar(
-      pedestrian, x = Time, y = Hourly_Counts, date = "Date"
+      hourly_peds, x = Time, y = Hourly_Counts, date = "Date"
     )
   )
 })
 
 test_that("The grouped data", {
-  grp_cal <- pedestrian %>%
+  grp_cal <- hourly_peds %>%
     group_by(Sensor_ID) %>%
     frame_calendar(x = Time, y = Hourly_Counts, date = Date)
   expect_is(grp_cal, "tbl_cal")
@@ -121,11 +121,10 @@ test_that("The grouped data", {
 })
 
 test_that("The tsibble data", {
-  skip_if(utils::packageVersion("tsibble") <= "0.7.0")
-  ped_ts <- pedestrian %>%
+  ped_ts <- hourly_peds %>%
     tsibble::as_tsibble(key = Sensor_Name, index = Date_Time)
   expect_equal(
-    pedestrian %>%
+    hourly_peds %>%
       frame_calendar(x = Time, y = Hourly_Counts, date = Date),
     ped_ts %>%
       frame_calendar(x = Time, y = Hourly_Counts, date = Date)
@@ -153,66 +152,45 @@ test_that("The tsibble data", {
 test_that("The arguments width & heigth", {
   expect_error(
     frame_calendar(
-      pedestrian, x = Time, y = Hourly_Counts, date = Date, width = 2
+      hourly_peds, x = Time, y = Hourly_Counts, date = Date, width = 2
     )
   )
   expect_error(
     frame_calendar(
-      pedestrian, x = Time, y = Hourly_Counts, date = Date, height = 2
+      hourly_peds, x = Time, y = Hourly_Counts, date = Date, height = 2
     )
   )
 })
 
-test_that("The argument sunday", {
-  expect_message(
-    frame_calendar(
-      pedestrian, x = Time, y = Hourly_Counts, date = Date, calendar = "weekly",
-      sunday = TRUE
-    )
-  )
-  expect_message(
-    frame_calendar(
-      pedestrian, x = Time, y = Hourly_Counts, date = Date, calendar = "daily",
-      sunday = TRUE
-    )
-  )
-  expect_warning(
-    frame_calendar(
-      pedestrian, x = Time, y = Hourly_Counts, date = Date, sunday = TRUE
-    ),
-    "deprecated."
-  )
-})
-
 test_that("The arguments nrow & ncol", {
   expect_message(
     frame_calendar(
-      pedestrian, x = Time, y = Hourly_Counts, date = Date, calendar = "daily",
+      hourly_peds, x = Time, y = Hourly_Counts, date = Date, calendar = "daily",
       ncol = 4
     )
   )
   expect_message(
     frame_calendar(
-      pedestrian, x = Time, y = Hourly_Counts, date = Date, calendar = "weekly",
+      hourly_peds, x = Time, y = Hourly_Counts, date = Date, calendar = "weekly",
       nrow = 4
     )
   )
 })
 
 test_that("The identity 1", {
-  cal <- frame_calendar(pedestrian, x = 1, y = Hourly_Counts, date = Date)
+  cal <- frame_calendar(hourly_peds, x = 1, y = Hourly_Counts, date = Date)
   cn_cal <- colnames(cal)
   expect_true(".x" %in% cn_cal)
 
-  cal <- frame_calendar(pedestrian, x = Time, y = 1, date = Date)
+  cal <- frame_calendar(hourly_peds, x = Time, y = 1, date = Date)
   cn_cal <- colnames(cal)
   expect_true(".y" %in% cn_cal)
 
-  cal <- frame_calendar(pedestrian, x = 1, y = 1, date = Date)
+  cal <- frame_calendar(hourly_peds, x = 1, y = 1, date = Date)
   cn_cal <- colnames(cal)
   expect_true(all(c(".x", ".y") %in% cn_cal))
 
-  ped <- rename(pedestrian, .x = Date_Time)
+  ped <- rename(hourly_peds, .x = Date_Time)
   expect_error(
     frame_calendar(ped, x = 1, y = Hourly_Counts, date = Date)
   )
@@ -223,26 +201,26 @@ test_that("The identity 1", {
 })
 
 test_that("The argument dir", {
-  hcal <- frame_calendar(pedestrian, x = Time, y = Hourly_Counts, date = Date)
-  vcal <- frame_calendar(pedestrian, x = Time, y = Hourly_Counts, date = Date,
+  hcal <- frame_calendar(hourly_peds, x = Time, y = Hourly_Counts, date = Date)
+  vcal <- frame_calendar(hourly_peds, x = Time, y = Hourly_Counts, date = Date,
     dir = "v")
   expect_equal(dim(hcal), dim(vcal))
 })
 
 test_that("The argument polar", {
-  ccal <- frame_calendar(pedestrian, x = Time, y = Hourly_Counts, date = Date)
-  pcal <- frame_calendar(pedestrian, x = Time, y = Hourly_Counts, date = Date,
+  ccal <- frame_calendar(hourly_peds, x = Time, y = Hourly_Counts, date = Date)
+  pcal <- frame_calendar(hourly_peds, x = Time, y = Hourly_Counts, date = Date,
     polar = TRUE)
   expect_equal(dim(ccal), dim(pcal))
 })
 
 test_that("The output", {
-  cal <- frame_calendar(pedestrian, x = Time, y = Hourly_Counts, date = Date)
+  cal <- frame_calendar(hourly_peds, x = Time, y = Hourly_Counts, date = Date)
   expect_is(cal, c("tbl_cal", "tbl_df"))
-  expect_equal(nrow(cal), nrow(pedestrian))
-  expect_equal(ncol(cal), ncol(pedestrian) + 2)
+  expect_equal(nrow(cal), nrow(hourly_peds))
+  expect_equal(ncol(cal), ncol(hourly_peds) + 2)
 
-  pedestrian2 <- sample_frac(pedestrian)
-  cal2 <- frame_calendar(pedestrian2, x = Time, y = Hourly_Counts, date = Date)
+  hourly_peds2 <- sample_frac(hourly_peds)
+  cal2 <- frame_calendar(hourly_peds2, x = Time, y = Hourly_Counts, date = Date)
   expect_equal(cal, cal2)
 })
